Structs
For storing a single argument.
Stores a
Box<> to argument variable, as well as a used flag.A struct for wrapping base argument data, of any type.
Stores an
IndexMap of Args. See examples.Enums
An error struct for passing errors up the callchain.